@@ -1,4 +1,4 @@
-#' Definition of UV-B waveband
+#' Constructor of UV-B waveband
 #'
 #' UV-B according to CIE and ISO standrads: 280--315 nm. UV-B according to
 #' common non-standard practice: 280--320 nm. UV-B according to medical or
@@ -23,17 +23,17 @@
 #'
 UVB <- function(std="ISO") {
   label <- "UVB"
-  if (std=="ISO" || std=="CIE"){
-    return(new_waveband(w.low=280, w.high=315,
-                        wb.name=paste(label, std, sep="."), wb.label=label))
-  } else if (std=="medical"){
-    return(new_waveband(w.low=290, w.high=320,
-                        wb.name=paste(label, std, sep="."), wb.label=label))
-  } else if (std=="none"){
-    return(new_waveband(w.low=280, w.high=320,
-                        wb.name=paste(label, std, sep="."), wb.label=label))
+  if (std=="ISO" || std=="CIE") {
+    new_waveband(w.low=280, w.high=315,
+                 wb.name=paste(label, std, sep="."), wb.label=label)
+  } else if (std=="medical") {
+    new_waveband(w.low=290, w.high=320,
+                 wb.name=paste(label, std, sep="."), wb.label=label)
+  } else if (std=="none") {
+    new_waveband(w.low=280, w.high=320,
+                 wb.name=paste(label, std, sep="."), wb.label=label)
   } else {
-    warning("Unsupported value '", std, "' supplied for 'std'.")
-    return(NA)
+    warning("'std' = '", std, "' not implemented.")
+    NA
   }
 }
